PollResult

Enum PollResult 

pub enum PollResult {
    Pending,
    Ready,
    Cancelled,
}
The outcome of a single poll.

Cancelled is recorded when a future is dropped before completing (its last poll returned Pending and no Ready event was ever emitted).

Examples

use async_reify::PollResult;

let ready = PollResult::Ready;
let pending = PollResult::Pending;
assert_ne!(ready, pending);

Variants



Pending

The future returned Poll::Pending.



Ready

The future returned Poll::Ready.



Cancelled

The future was dropped before completing.